<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es">
<context>
    <name>notification::BubbleItem</name>
    <message>
        <source>just now</source>
        <translation>Ahora mismo</translation>
    </message>
    <message>
        <source>1 new message</source>
        <translation>1 mensaje nuevo</translation>
    </message>
</context>
<context>
    <name>notification::BubbleModel</name>
    <message>
        <source>%1 minutes ago</source>
        <translation>Hace %1 minutos</translation>
    </message>
</context>
</TS>